<?php
/**
 * Customizer active callbacks
 *
 * @package Theme Palace
 * @subpackage Mezze
 * @since Mezze 1.0.0
 */

if ( ! function_exists( 'mezze_is_breadcrumb_enable' ) ) :
	/**
	 * Check if breadcrumb is enabled.
	 *
	 * @since Mezze 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function mezze_is_breadcrumb_enable( $control ) {
		return $control->manager->get_setting( 'mezze_theme_options[breadcrumb_enable]' )->value();
	}
endif;

if ( ! function_exists( 'mezze_is_pagination_enable' ) ) :
	/**
	 * Check if pagination is enabled.
	 *
	 * @since Mezze 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function mezze_is_pagination_enable( $control ) {
		return $control->manager->get_setting( 'mezze_theme_options[pagination_enable]' )->value();
	}
endif;

/**
 * Front Page Active Callbacks
 */


/**
 * Check if slider section is enabled.
 *
 * @since Mezze 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mezze_is_slider_section_enable( $control ) {
	return ( $control->manager->get_setting( 'mezze_theme_options[slider_section_enable]' )->value() );
}

/**
 * Check if about section is enabled.
 *
 * @since Mezze 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mezze_is_about_section_enable( $control ) {
	return ( $control->manager->get_setting( 'mezze_theme_options[about_section_enable]' )->value() );
}

/**
 * Check if special menu section is enabled.
 *
 * @since Mezze 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mezze_is_special_menu_section_enable( $control ) {
	return ( $control->manager->get_setting( 'mezze_theme_options[special_menu_section_enable]' )->value() );
}

/**
 * Check if special menu section seperator.
 *
 * @since Mezze 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mezze_is_special_menu_section_content_seperator_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mezze_theme_options[special_menu_content_type]' )->value();
	return mezze_is_special_menu_section_enable( $control ) && ( in_array( $content_type, array( 'page', 'post' ) ) );
}

/**
 * Check if special menu section content type is page.
 *
 * @since Mezze 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mezze_is_special_menu_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mezze_theme_options[special_menu_content_type]' )->value();
	return mezze_is_special_menu_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if special menu section content type is product.
 *
 * @since Mezze 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mezze_is_special_menu_section_content_product_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mezze_theme_options[special_menu_content_type]' )->value();
	return mezze_is_special_menu_section_enable( $control ) && ( 'product' == $content_type );
}

/**
 * Check if service section is enabled.
 *
 * @since Mezze 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mezze_is_service_section_enable( $control ) {
	return ( $control->manager->get_setting( 'mezze_theme_options[service_section_enable]' )->value() );
}

/**
 * Check if blog section is enabled.
 *
 * @since Mezze 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mezze_is_blog_section_enable( $control ) {
	return ( $control->manager->get_setting( 'mezze_theme_options[blog_section_enable]' )->value() );
}

/**
 * Check if blog section content type is category.
 *
 * @since Mezze 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mezze_is_blog_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mezze_theme_options[blog_content_type]' )->value();
	return mezze_is_blog_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if blog section content type is recent.
 *
 * @since Mezze 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mezze_is_blog_section_content_recent_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mezze_theme_options[blog_content_type]' )->value();
	return mezze_is_blog_section_enable( $control ) && ( 'recent' == $content_type );
}
