<?php
/**
 * Service Section options
 *
 * @package Theme Palace
 * @subpackage Mezze
 * @since Mezze 1.0.0
 */

// Add Service section
$wp_customize->add_section( 'mezze_service_section', array(
	'title'             => esc_html__( 'Services','mezze' ),
	'description'       => esc_html__( 'Services Section options.', 'mezze' ),
	'panel'             => 'mezze_front_page_panel',
) );

// Service content enable control and setting
$wp_customize->add_setting( 'mezze_theme_options[service_section_enable]', array(
	'default'			=> 	$options['service_section_enable'],
	'sanitize_callback' => 'mezze_sanitize_switch_control',
) );

$wp_customize->add_control( new Mezze_Switch_Control( $wp_customize, 'mezze_theme_options[service_section_enable]', array(
	'label'             => esc_html__( 'Service Section Enable', 'mezze' ),
	'section'           => 'mezze_service_section',
	'on_off_label' 		=> mezze_switch_options(),
) ) );

// service title setting and control
$wp_customize->add_setting( 'mezze_theme_options[service_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['service_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'mezze_theme_options[service_title]', array(
	'label'           	=> esc_html__( 'Title', 'mezze' ),
	'section'        	=> 'mezze_service_section',
	'active_callback' 	=> 'mezze_is_service_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'mezze_theme_options[service_title]', array(
		'selector'            => '#our-services .section-header h2.section-title',
		'settings'            => 'mezze_theme_options[service_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'mezze_service_title_partial',
    ) );
}

// Service image setting and control.
$wp_customize->add_setting( 'mezze_theme_options[service_image]', array(
	'sanitize_callback' => 'mezze_sanitize_image'
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'mezze_theme_options[service_image]',
		array(
		'label'       		=> esc_html__( 'Seperator Image', 'mezze' ),
		'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'mezze' ), 500, 550 ),
		'section'     		=> 'mezze_service_section',
		'active_callback'	=> 'mezze_is_service_section_enable',
) ) );


for ( $i = 1; $i <= 4; $i++ ) :

	// service note control and setting
	$wp_customize->add_setting( 'mezze_theme_options[service_content_icon_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( new Mezze_Icon_Picker( $wp_customize, 'mezze_theme_options[service_content_icon_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Icon %d', 'mezze' ), $i ),
		'section'           => 'mezze_service_section',
		'active_callback'	=> 'mezze_is_service_section_enable',
	) ) );

	// service pages drop down chooser control and setting
	$wp_customize->add_setting( 'mezze_theme_options[service_content_page_' . $i . ']', array(
		'sanitize_callback' => 'mezze_sanitize_page',
	) );

	$wp_customize->add_control( new Mezze_Dropdown_Chooser( $wp_customize, 'mezze_theme_options[service_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'mezze' ), $i ),
		'section'           => 'mezze_service_section',
		'choices'			=> mezze_page_choices(),
		'active_callback'	=> 'mezze_is_service_section_enable',
	) ) );

	// service hr setting and control
	$wp_customize->add_setting( 'mezze_theme_options[service_hr_'. $i .']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new Mezze_Customize_Horizontal_Line( $wp_customize, 'mezze_theme_options[service_hr_'. $i .']',
		array(
			'section'         => 'mezze_service_section',
			'active_callback' => 'mezze_is_service_section_enable',
			'type'			  => 'hr'
	) ) );
endfor;
